summaryrefslogtreecommitdiffstats
path: root/lib/public/files
diff options
context:
space:
mode:
authorRobin Appelman <icewind@owncloud.com>2015-12-03 14:10:05 +0100
committerRobin Appelman <icewind@owncloud.com>2016-01-20 16:32:56 +0100
commitbe380accb90d0a4f72a56a1166072b20731b0083 (patch)
treea6d276701c4ae1dcf9fb544f3b67abc7ec7d738e /lib/public/files
parent99415a9f7fa26a990848c2cb63333552c1619729 (diff)
downloadnextcloud-server-be380accb90d0a4f72a56a1166072b20731b0083.tar.gz
nextcloud-server-be380accb90d0a4f72a56a1166072b20731b0083.zip
clear mount cache when deleting user
Diffstat (limited to 'lib/public/files')
-rw-r--r--lib/public/files/config/iusermountcache.php10
1 files changed, 9 insertions, 1 deletions
diff --git a/lib/public/files/config/iusermountcache.php b/lib/public/files/config/iusermountcache.php
index 156ebbf448c..888e5d41e24 100644
--- a/lib/public/files/config/iusermountcache.php
+++ b/lib/public/files/config/iusermountcache.php
@@ -31,7 +31,7 @@ use OCP\IUser;
*/
interface IUserMountCache {
/**
* Register a mount for a user to the cache
*
* @param IUser $user
* @param IMountPoint[] $mounts
@@ -59,4 +59,12 @@ interface IUserMountCache {
* @since 9.0.0
*/
public function getMountsForRootId($rootFileId);
+
+ /**
+ * Remove all cached mounts for a user
+ *
+ * @param IUser $user
+ * @since 9.0.0
+ */
+ public function removeUserMounts(IUser $user);
}
@@ -31,7 +31,7 @@ use OCP\IUser;
interface IUserMountCache {
/**
- * Register a mount for a user to the cache
+ * Register mounts for a user to the cache
*
* @param IUser $user